@@ -1,16 +1,20 @@
 #!/usr/bin/env perl
 package NetHack::Inventory::Equipment;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moose;
 with 'NetHack::ItemPool::Role::HasPool';
 
-my @weapon_slots = (qw/weapon offhand quiver/);
-my @armor_slots = (qw/helmet gloves boots bodyarmor cloak shirt shield/);
-my @accessory_slots = (qw/left_ring right_ring amulet/);
-my @eq_slots = (@weapon_slots, @armor_slots, @accessory_slots);
+sub weapon_slots { qw/weapon offhand quiver/ }
+sub armor_slots  { qw/helmet gloves boots bodyarmor cloak shirt shield/ }
+sub accessory_slots { qw/left_ring right_ring amulet/ }
 
-for my $slot (@eq_slots) {
+sub slots {
+    my $self = shift;
+    return ($self->weapon_slots, $self->armor_slots, $self->accessory_slots)
+}
+
+for my $slot (__PACKAGE__->slots) {
     has $slot => (
         is        => 'rw',
         isa       => 'NetHack::Item',
@@ -44,9 +48,12 @@ sub _update_ring {
 
     if ($item->type eq 'ring' && (my $hand = $item->hand)) {
         my $slot = "${hand}_ring";
-        my $clearer = "clear_$slot";
-        $self->$clearer;
-        $self->$slot($item);
+
+        if ($item != ($self->$slot || 0)) {
+            my $clearer = "clear_$slot";
+            $self->$clearer;
+            $self->$slot($item);
+        }
     }
 }
 
@@ -56,12 +63,12 @@ sub _update_weapon {
 
     for my $slot (keys %weapon_slots) {
         my $check = $weapon_slots{$slot};
+        next unless $item->$check;
+        next if $self->$slot && $self->$slot == $item;
 
-        if ($item->$check) {
-            my $clearer = "clear_$slot";
-            $self->$clearer;
-            $self->$slot($item);
-        }
+        my $clearer = "clear_$slot";
+        $self->$clearer;
+        $self->$slot($item);
     }
 }
 
@@ -72,28 +79,14 @@ sub _update_armor {
     return unless $item->does('NetHack::Item::Role::Wearable');
 
     if ($item->is_worn) {
-        my %types = (
-            amulet    => ['amulet'],
-            helmet    => ['armor', 'helmet'],
-            gloves    => ['armor', 'gloves'],
-            boots     => ['armor', 'boots'],
-            bodyarmor => ['armor', 'bodyarmor'],
-            cloak     => ['armor', 'cloak'],
-            shirt     => ['armor', 'shirt'],
-            shield    => ['armor', 'shield'],
-        );
-
-        for my $slot (keys %types) {
-            my ($type, $subtype) = @{ $types{$slot} };
-            next if $item->type ne $type;
-            next if $subtype && $item->subtype ne $subtype;
+        my $slot = $item->type eq 'armor'
+                 ? $item->subtype
+                 : $item->type;
 
+        if ($item != ($self->$slot || 0)) {
             my $clearer = "clear_$slot";
             $self->$clearer;
-
             $self->$slot($item);
-
-            last;
         }
     }
 }
@@ -102,16 +95,16 @@ sub remove {
     my $self = shift;
     my $item = shift;
 
-    for my $eq_slot (@eq_slots) {
-        my $in_slot = $self->$eq_slot;
+    for my $slot (__PACKAGE__->slots) {
+        my $incumbent = $self->$slot;
 
-        next unless $in_slot
-                 && $in_slot->slot eq $item->slot;
+        next unless $incumbent
+                 && $incumbent->slot eq $item->slot;
 
-        my $clearer = "clear_$eq_slot";
+        my $clearer = "clear_$slot";
         $self->$clearer;
     }
-};
+}
 
 for my $slot (keys %weapon_slots) {
     my $accessor = $weapon_slots{$slot};
@@ -119,15 +112,16 @@ for my $slot (keys %weapon_slots) {
     before "clear_$slot" => sub {
         my $self = shift;
         my $item = $self->$slot or return;
-        $item->$accessor(0);
+        $item->$accessor(0) if $item->$accessor;
     };
 };
 
-for my $slot (@armor_slots) {
+for my $slot (__PACKAGE__->armor_slots) {
     before "clear_$slot" => sub {
         my $self = shift;
         my $item = $self->$slot or return;
-        $item->is_worn(0);
+
+        $item->is_worn(0) if $item->is_worn;
     };
 }
 
@@ -135,7 +129,7 @@ for my $hand (qw/left_ring right_ring/) {
     before "clear_$hand" => sub {
         my $self = shift;
         my $item = $self->$hand or return;
-        $item->hand(undef);
+        $item->hand(undef) if $item->hand;
     };
 }
 
@@ -152,7 +146,7 @@ NetHack::Inventory::Equipment - the player's equipment
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
