@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 package NetHack::Item::Armor;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moose;
 extends 'NetHack::Item';
@@ -11,9 +11,11 @@ with 'NetHack::Item::Role::Damageable';
 use constant subtypes => qw(helmet shirt bodyarmor cloak gloves shield boots);
 use constant type => "armor";
 
+sub base_ac { shift->collapse_spoiler_value('ac') }
+
 sub ac {
     my $self = shift;
-    my $base = $self->collapse_spoiler_value('ac');
+    my $base = $self->base_ac;
     return $base unless defined($base) && $self->enchantment_known;
 
     my $enchantment = $self->enchantment;
