@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 package NetHack::Item::Spoiler::Potion;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use strict;
 use warnings;
@@ -97,7 +97,7 @@ sub _list {
         },
     };
 
-    return $potions, (weight => 20, appearances => \@potions,
+    return $potions, (weight => 20, appearances => \@potions, stackable => 1,
                       plural => sub {
                         my $name = shift;
                         $name =~ s/\bpotion\b/potions/;
